/*
 * @file compass.h
 * @author: Michael Burmeister
 * @date: January 12, 2015
 * @version 1.0
 * Configure Magnometer HMC5883L
*/

#ifndef COMPASS_H
#define COMPASS_H

#include "simplei2c.h"

/*
 *@brief Open connection to compass
 *
 *@parms Clock Pin,m Data Pin, Mode of operation
*/
int Compass_Open(int SCL, int DTA, int Mode);

/*
 *@brief Close connection to compass
 *
 *@parms None
 *
*/
void Compass_Close();

/*
 *@brief Get compass data for x, y and z
 *
 *@parms pointer to x, pointer to y, pointer to z
 *
 */
void Compass_Read(int *X, int *Y, int *Z);

/*
 *@brief Set the compass gain factor 0 high and 7 low
 *
 *@parms gain value
 *
 */
void Compass_SetGain(int g);

/*
 *@brief Get current compass gain value
 *
 *@parms None
 *
 */
int Compass_GetGain(void);


#define MSingle 0x01
#define MContinues 0x00
#define MIdle 0x10
#define MAdd 0x3c
#define MModr 0x02
#define MConfa 0x00
#define MConfb 0x01
#define MDReg 0x03
#define MStatus 0x09

#endif