/*
 * @brief Real time compass library
 * @author: Michael Burmeister
 * @date: January 13, 2015
 * @version 1.0
 * 
*/

#include "simpletools.h"
#include "compass.h"

void Get_Max(int, int, int);


#define SCL 4
#define SDA 5

int ox, oy, oz;
int lx, ly, lz;
int hx, hy, hz;


int main(void)
{
  int count;
  
  lx = 1000;
  ly = 1000;
  lz = 1000;
  hx = -1000;
  hy = -1000;
  hz = -1000;
  
  int x, y, z;                                // Declare x, y, & z axis variables

  Compass_Open(SCL, SDA, MContinues);         // Start Compass process

  // Offset to make direction work
  ox = 313;
  oy = -5;
  oz = -892;

  count = 0;
  print("Count, X, Y, Z, Deg\n");
  pause(1000);
  
  // Changing Gain makes the numbers smaller
  Compass_SetGain(1);
  pause(1000);
  
  for(int i=0;i<120;i++)                                    // Take a circler collection of data
  {
    Compass_Read(&x, &y, &z);                               // Get the Compass values
    count++;
    
    Get_Max(x, y, z);
    
    x -= ox;
    y -= oy;
    z -= oz;
    
    float heading = atan2(y, x);
    if (heading < 0)                                           // Fix negative readings
        heading += 2 * PI;
             
    float headingDegrees = heading * 180/PI;                   // Convert to degrees from Radians

    print("%d, %d, %d, %d,  ",                                 // Display Compass values
          count, x, y, z);
    print("%3.0f \n",                                          // Display Heading value
          headingDegrees);
    
    pause(250);                                                // Wait 1/4 second for you
  }

  print("Max: %d, %d, %d\n", hx, hy, hz);
  print("Low: %d, %d, %d\n", lx, ly, lz);
  x = (hx - lx)/2;
  y = (hy - ly)/2;
  z = (hz - lz)/2;
  print("Offset: %d, %d, %d\n", hx-x, hy-y, hz-z);             // These are the values for ox, oy, oz
  
  Compass_Close();                                             // Shutdown cog with Compass
  return 0;
}

void Get_Max(int x, int y, int z)
{
    if (x < lx)
        lx = x;
    if (y < ly)
        ly = y;
    if (z < lz)
        lz = z;
    if (x > hx)
        hx = x;
    if (y > hy)
        hy = y;
    if (z > hz)
        hz = z;
}
